A class to represent a MetaPhlAn profile
Source:R/metaphlanProfile-class.R
metaphlanProfile-class.RdThis class stores database version information and taxonomic profile data from MetaPhlAn output.
R/metaphlanProfile-class.R
metaphlanProfile-class.RdThis class stores database version information and taxonomic profile data from MetaPhlAn output.