Extracts or updates the core taxonomic abundance data from a
metaphlanProfile object.
The taxonomic profile is stored as a data.frame containing taxonomic
identifiers (clade_name) and relative abundances per sample.
Extracts or updates the core taxonomic abundance data from a
metaphlanProfile object.
The taxonomic profile is stored as a data.frame containing taxonomic
identifiers (clade_name) and relative abundances per sample.