A S4 class extending phyloseq for microbiome data analysis
Source:R/microEDA-class.R
microEDA-class.RdThis class inherits from phyloseq and adds a slot for
additional information, such as lowest taxonomic rank, MetaPhlAn database
version, applied transformations and/or filters.
show() displays a summary of a microEDA object, including the standard
phyloseq output and information from the info slot.
Usage
microEDA(tax_profile, metadata = NULL, sample_column = NULL)
# S4 method for class 'metaphlanProfile'
microEDA(tax_profile, metadata = NULL, sample_column = NULL)
# S4 method for class 'phyloseq'
microEDA(tax_profile, metadata = NULL, sample_column = NULL)
# S4 method for class 'microEDA'
show(object)Details
When passed a metaphlanProfile, the profile will be returned at
the lowest available taxonomic rank, which usually is at strain rank. To
agglomerate the profile at a higher rank, please see agglomerate_taxa().
Slots
infoA
listcontaining metadata.otu_tableA
matrixof classotu_tablewith taxa as rows and samples as columns.tax_tableA named
character matrixof classtaxonomyTable, with taxon IDs as row names and taxonomic ranks as columns.sam_dataAn object of class
sample_datacontaining sample metadata.phy_treeAn object of class
phylorepresenting a phylogenetic tree.refseqAn object of a class inheriting from
XStringSet-class(e.g.,DNAStringSet) containing biological sequences. SeeXStringSet.
Examples
data("GlobalPatterns", package = "phyloseq")
me <- microEDA(GlobalPatterns)